@@ -21,7 +21,7 @@ SUPPORTED_VALUES = {
     ],
     "number": [ "sg", "pl" ],
     "case": [
-        "nom", "gen", "dat", "acc", "inst", "loc", "postp", "pred"
+        "nom", "gen", "dat", "acc", "inst", "loc", "postp", "pred", "voc"
     ],
     "gender": [
         "m1", "m2", "m3", "f", "n1", "n2", "p1", "p2", "p3"
@@ -369,6 +369,7 @@ tense = gram('tense')
 nsyn = gram('nsyn')
 nsem = gram('nsem')
 T = gram('T')
+voc = gram('voc')
 nom = gram('nom')
 gen = gram('gen')
 dat = gram('dat')
